@@ -3,7 +3,9 @@ import pymssql
 
 class Database(object):
     def __init__(self, server, port, name, username, password):
-        self.connection = pymssql.connect(host=server, port=port, user=username, password=password, database=name)
+        self.connection = pymssql.connect(
+            host=server, port=port, user=username, password=password, database=name
+        )
 
     def execute_query(self, sql: str, params: tuple = ..., as_dict=False):
         cursor = self.connection.cursor(as_dict=as_dict)
