@@ -1,4 +1,6 @@
-GET_ATTACHMENT_PATH = "select ValueStr from x_UserSettings where Property = N'Путь к хранилищу прикреплённых файлов'"
+GET_ATTACHMENT_PATH = (
+    "select ValueStr from x_UserSettings where Property = N'Путь к хранилищу прикреплённых файлов'"
+)
 GET_FILETYPE_ID = "select FileTypeID from atf_FileType where Code = %s"
 CREATE_FILETYPE = "insert into atf_FileType (Code, Name) values (%s, %s)d"
 GET_DOCUMENT_GUID = "select GUID from x_DocTypeDef where HeadTable = 'hlt_MKAB'"
